@@ -103,13 +103,24 @@ void Settings::on_pushButton_Apply_clicked()
     mSettings.setValue("mem3Name", ui->lineEdit_mem3Name->text());
     mSettings.setValue("mem4Name", ui->lineEdit_mem4Name->text());
     setValue();
-    mSettings.sync();    
+    mSettings.sync();
+    mediaObject->stop();
 }
 
 void Settings::on_pushButton_Sound_clicked()
 {
     QString location = QDesktopServices::storageLocation(QDesktopServices::MusicLocation);
-    QString fileName = QFileDialog::getOpenFileName(this,tr("Open Sound"), location, "");
+    QString fileName = QFileDialog::getOpenFileName(this,tr("Open Sound"), location, "Audio (*.aac *.mp3 *.wav");
     mSettings.setValue("soundFile", fileName);
-//    ui->labelSound->setText(location);
+    mediaObject = new Phonon::MediaObject(this);
+    audioOutput = new Phonon::AudioOutput(Phonon::MusicCategory, this);
+    mediaPath = Phonon::createPath(mediaObject, audioOutput);
+    mediaObject->setCurrentSource(Phonon::MediaSource(mSettings.value("soundFile").toString()));
+    mediaObject->play();
+//    ui->labelSound->setText(fileName);
+}
+
+void Settings::rejected()
+{
+    mediaObject->stop();
 }
