@@ -4,6 +4,10 @@
 #include <QDialog>
 #include <QSettings>
 #include <QMessageBox>
+#include <Phonon/AudioOutput>
+#include <Phonon/MediaObject>
+#include <Phonon/Path>
+#include <Phonon/BackendCapabilities>
 
 
 namespace Ui {
@@ -22,9 +26,13 @@ protected:
 private:
     Ui::Settings *ui;
     QSettings mSettings;
+    Phonon::MediaObject *mediaObject;
+    Phonon::AudioOutput *audioOutput;
+    Phonon::Path mediaPath;
 
     void getValue();
     void setValue();
+    void rejected();
 
 private slots:
     void on_pushButton_Sound_clicked();
